@@ -2,7 +2,11 @@
 PyDoc_STRVAR(firebaseInit_doc,
 	"init the Firebase system \n"\
 	"\n"\
-	"firebase.init()");
+	"firebase.init(analytics=,messaging,remoteConfig)\n"\
+	"\n"\
+	"Parameters\n"\
+	"----------\n"\
+	"    analytics, messaging, remoteConfig : boolean (optional)");
 
 //firebase release
 PyDoc_STRVAR(firebaseRelease_doc,
@@ -246,4 +250,52 @@ PyDoc_STRVAR(firebaseRemoteConfigGetBoolean_doc,
 PyDoc_STRVAR(firebaseRemoteConfigFetch_doc,
 	"fetch the new data\n"\
 	"\n"\
-	"firebaseRemoteConfig.fetch()");
\ No newline at end of file
+	"firebaseRemoteConfig.fetch()");
+
+//firebase MLKit is supported or not
+PyDoc_STRVAR(firebaseMLKitIsSupported_doc,
+	"checking if the mlKit is supported by plarform or not \n"\
+	"\n"\
+	"firebaseMLKit.isSupported()\n"\
+	"\n"\
+	"Returns\n"\
+	"-------\n"\
+	"    result : boolean");
+
+//firebase MLKit init
+PyDoc_STRVAR(firebaseMLKitInit_doc,
+	"init the Firebase MLKit system \n"\
+	"\n"\
+	"firebaseMLKit.init()");
+
+//firebase MLKit release
+PyDoc_STRVAR(firebaseMLKitRelease_doc,
+	"release the Firebase MLKit system\n"\
+	"\n"\
+	"firebaseMLKit.release()");
+
+//firebase MLKit preview mode
+PyDoc_STRVAR(firebaseMLKitPreview_doc,
+	"preview the Firebase MLKit system\n"\
+	"\n"\
+	"firebaseMLKit.preview()");
+
+//firebase MLKit get contours point
+PyDoc_STRVAR(firebaseMLKitGetContours_doc,
+	"Get the contours point\n"\
+	"\n"\
+	"firebaseMLKit.getContours()\n"\
+	"\n"\
+	"Returns\n"\
+	"-------\n"\
+	"    result : list(float)");
+
+//firebase MLKit get head euler angle
+PyDoc_STRVAR(firebaseMLKitGetHeadEulerAngle_doc,
+	"Get the head euler angle\n"\
+	"\n"\
+	"firebaseMLKit.getHeadEulerAngle()\n"\
+	"\n"\
+	"Returns\n"\
+	"-------\n"\
+	"    result : tuple(y,z)");
\ No newline at end of file
